@@ -45,7 +45,7 @@ class AbiturientRegAts(Base):
 
     # Родитель
     parent_id = Column(ForeignKey('abiturient_reg_ats.id'))
-    parent = relationship('AbiturientRegAts')
+    parent = relationship('AbiturientRegAts', remote_side=[id])
 
     # Родители
     parents = Column(String(100))
