@@ -25,9 +25,18 @@ class Speciality(Base):
     name_ru = Column('speciality_name_ru', String(200))
     name_en = Column('speciality_name_en', String(200))
     code = Column('speciality_okpd', String(10))
+    requirements_kz = Column('speciality_requirements_kz', String)
+    requirements_ru = Column('speciality_requirements_ru', String)
+    requirements_en = Column('speciality_requirements_en', String)
     description_kz = Column('speciality_discription_kz', String)
     description_ru = Column('speciality_discription_ru', String)
     description_en = Column('speciality_discription_en', String)
+    further_study_kz = Column('speciality_access_further_study_kz', String)
+    further_study_ru = Column('speciality_access_further_study_ru', String)
+    further_study_en = Column('speciality_access_further_study_en', String)
+    prof_status_kz = Column('speciality_prof_status_kz', String)
+    prof_status_ru = Column('speciality_prof_status_ru', String)
+    prof_status_en = Column('speciality_prof_status_en', String)
     result_ru = Column(String)
     result_kz = Column(String)
     result_en = Column(String)
